@@ -36,25 +36,25 @@
 // and then checked back in. You cannot make changes to these sections without
 // corresponding changes to the buildmeister script
 #ifndef NV_BUILD_BRANCH
-    #define NV_BUILD_BRANCH             VK571_25
+    #define NV_BUILD_BRANCH             r570_00
 #endif
 #ifndef NV_PUBLIC_BRANCH
-    #define NV_PUBLIC_BRANCH             VK571_25
+    #define NV_PUBLIC_BRANCH             r570_00
 #endif
 
 #if defined(NV_LINUX) || defined(NV_BSD) || defined(NV_SUNOS)
-#define NV_BUILD_BRANCH_VERSION         "rel/gpu_drv/r570/VK571_25-359"
-#define NV_BUILD_CHANGELIST_NUM         (36190327)
+#define NV_BUILD_BRANCH_VERSION         "rel/gpu_drv/r570/r570_00-486"
+#define NV_BUILD_CHANGELIST_NUM         (36118394)
 #define NV_BUILD_TYPE                   "Official"
-#define NV_BUILD_NAME                   "rel/gpu_drv/r570/VK571_25-359"
-#define NV_LAST_OFFICIAL_CHANGELIST_NUM (36190327)
+#define NV_BUILD_NAME                   "rel/gpu_drv/r570/r570_00-486"
+#define NV_LAST_OFFICIAL_CHANGELIST_NUM (36118394)
 
 #else     /* Windows builds */
-#define NV_BUILD_BRANCH_VERSION         "VK571_25-16"
-#define NV_BUILD_CHANGELIST_NUM         (36190327)
+#define NV_BUILD_BRANCH_VERSION         "r570_00-483"
+#define NV_BUILD_CHANGELIST_NUM         (36118394)
 #define NV_BUILD_TYPE                   "Official"
-#define NV_BUILD_NAME                   "573.52"
-#define NV_LAST_OFFICIAL_CHANGELIST_NUM (36190327)
+#define NV_BUILD_NAME                   "573.42"
+#define NV_LAST_OFFICIAL_CHANGELIST_NUM (36118394)
 #define NV_BUILD_BRANCH_BASE_VERSION    R570
 #endif
 // End buildmeister python edited section
